package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.MobileMiddle;

/**
 * 双向呼叫号码Service接口
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
public interface IMobileMiddleService 
{
    /**
     * 查询双向呼叫号码
     * 
     * @param id 双向呼叫号码主键
     * @return 双向呼叫号码
     */
    public MobileMiddle selectMobileMiddleById(Long id);

    /**
     * 查询双向呼叫号码列表
     * 
     * @param mobileMiddle 双向呼叫号码
     * @return 双向呼叫号码集合
     */
    public List<MobileMiddle> selectMobileMiddleList(MobileMiddle mobileMiddle);

    /**
     * 新增双向呼叫号码
     * 
     * @param mobileMiddle 双向呼叫号码
     * @return 结果
     */
    public int insertMobileMiddle(MobileMiddle mobileMiddle);

    /**
     * 修改双向呼叫号码
     * 
     * @param mobileMiddle 双向呼叫号码
     * @return 结果
     */
    public int updateMobileMiddle(MobileMiddle mobileMiddle);

    /**
     * 批量删除双向呼叫号码
     * 
     * @param ids 需要删除的双向呼叫号码主键集合
     * @return 结果
     */
    public int deleteMobileMiddleByIds(Long[] ids);

    /**
     * 删除双向呼叫号码信息
     * 
     * @param id 双向呼叫号码主键
     * @return 结果
     */
    public int deleteMobileMiddleById(Long id);
}
